*--------------------*
*     Programs       *
*--------------------*

* Programs distributed by Stata
ssc install mdesc
ssc install unique
ssc install estout


* Own Programs


*-----------------------------------------------------------------------------*

capture program drop own_ineq
program own_ineq

	syntax varname [if] [,  by(varname) GENSim(name) GENEnt(name) GENDis(name) GENEVen(name) GENM2(name) ]

tempvar n1 N1 p1 uniq obs_uniq first freq simpson entrop dissim M1 M2 M6 evenness 
quiet {
bys `by' `1' : gen `n1' = _N
by  `by'      : gen `N1' = _N

gen `p1' = `n1'/`N1'

gen `simpson' = `p1'^2/`n1'
by `by' : replace `simpson' = sum(`simpson')
by `by' : replace `simpson' = `simpson'[_N]
gen `M1' = 1-`simpson'


gen `entrop' = `p1'*ln(1/`p1') * 1/`n1'
by `by' :replace `entrop' = sum(`entrop')
by `by' :replace `entrop' = `entrop'[_N]


** Need to expand this to cover cases when one group variable is missing in some groups
qui bys `1': gen byte `uniq' =  _n==_N
replace `uniq' = sum(`uniq')
replace `uniq' = `uniq'[_N]
 
qui bys `by' `1': gen byte `obs_uniq' = _n==_N
by `by': replace `obs_uniq' = sum(`obs_uniq')
by `by' :replace `obs_uniq' = `obs_uniq'[_N]

gen `dissim' = abs(`p1' - 1/`uniq')* 1/(2*`n1')
replace `dissim' = `dissim'+(`uniq'-`obs_uniq')*1/`uniq'*1/(2*`N1')
by `by' : replace `dissim' = sum(`dissim')
by `by' : replace `dissim' = `dissim'[_N]

gen `M2' = `uniq'/(`uniq'-1) * `M1'

gen `M6' = (`p1'-1/`N1')/`n1'
by `by' : replace `M6' = sum(`M6')
by `by' : replace `M6' = `M6'[_N]
replace `M6' = `uniq'*(1-`M6')

gen `evenness' = exp(`entrop')/`obs_uniq'

bys  `by' : gen `first' = _n == 1 
bys  `by' : gen `freq'  = string(`N1')

label var `freq' 	"Freq."		
label var `simpson' "Simpson"
label var `entrop' 	"Entropy "
label var `dissim' 	"Dissim."
}

if "`format'" == ""  local format "%4.3f" 
tabdisp `by' if `first'==1 , c( `freq' `simpson' `entrop' `dissim') format(`format')


local allvars `simpson' `entrop' `dissim' `evenness' `M2'

local i =1
foreach var in gensim genent gendis geneven genm2{
if "``var''"!=""{
confirm e var ``var''
if _rc!=0{
	di as error "Variable `gens' already in data" "Variable not replaced"
	continue
	}
	
local newvar : word `i' of `allvars'	
gen ``var'' =  `newvar'
}
local ++i

}



end program

*-----------------------------------------------------------------------------*

capture program drop stdize
program stdize  
syntax varlist  , by(varlist) weights(varname)
 

quiet{
tempvar t_mean t_sd group
 
gen `t_mean' 	= . 
gen `t_sd' 		= .

egen `group' = group(`by')

levelsof `group', local(cc)

foreach var in `varlist'{
foreach c in `cc'{
sum `var' if 	`group'==`c' 	[aw=`weights']
replace `t_mean' 	= `r(mean)' if `group'==`c'
replace `t_sd' 		= `r(sd)' 	if `group'==`c'
}
replace `var' = (`var'-`t_mean')/`t_sd'
}

}


 

end program

exit

