*-----------------------------------------------------------------*
*            Data from Structure of Earnings Survey               *
*-----------------------------------------------------------------*

 
cd "$eu_ses"

global datas :  dir  . files "*.dta"
di `"$datas"'

local i =0
foreach ds in $datas{

local ++i

use "`ds'" , clear
tokenize "`ds'" , parse("_" ".")

local cc	= "`7'"
local year 	= "`5'"

 
if inlist(`year',2002,2006) {
	local isco2d isco88_2d
	local isco3d isco88_3d
	}
else{	
	local isco2d isco08_2d
	local isco3d isco08_3d
	}
 
 
if "`cc'"=="de" & `year'!=2014{
	gen country ="DE"
} 

capture replace `isco3d' =0 if `isco3d'==.

 
** Additional characteristics 

foreach var in prime_age high_edu ten{
	capture drop `var'
	}

gen prime_age = age>=20 & age<=55  
gen high_edu = educ==3
 
if "`cc'"=="NLD" & `year'<2008{
gen ten = 0 
replace ten =1 if b26=="Year1_4"  |  b26=="Year0_<1" 
}
else{
capture destring b26, replace force
gen ten = b26 <5
}


 
** Missing variables
 
foreach var in pub no_col{
	mdesc `var'
	local share = `r(percent)'

	quiet sum `var'
	if `r(sd)' == 0 | `share'>20 replace `var' =0
	}


capture drop w
gen w = 1

capture drop N_obs
quiet count
gen N_obs= r(N)


** HH indices for industry
*-------------------------------------

foreach x in 2 3 {
capture drop indus_i occupa_t 
egen indus_i = count(1), by(nace `isco`x'd')
egen occupa_t = count(1), by(`isco`x'd')
egen hh`x'	= sum((indus_i/occupa_t)^2*1/indus_i), by(`isco`x'd')
}

quiet tab nace
gen n_indus = `r(r)'
encode nace, gen(nnace)


**	Winner-takes-all measures
*------------------------------------------

egen occ_90 = pctile(hwage), p(90)  by(`isco2d')
egen occ_10 = pctile(hwage), p(10)  by(`isco2d')
gen top_10 = hwage>occ_90
gen bott_10 = hwage<occ_10

egen share_1 = total(hwage*top_10), by(`isco2d')
egen share_10 = total(hwage*bott_10), by(`isco2d')

gen s1_s10 = share_1/share_10



** Residual wages: different specifications
*-------------------------------------------------
global xvars "fem i.age i.educ i.size_d part i.nnace pub ten part indef overt"
global few_x "fem i.age i.educ i.size_d i.nnace overt"

if "`cc'" == "italy" &  "`year'" =="2010"{
replace hwage = hwage_own
}


capture drop lwage
gen lwage = log(hwage) 


xi: qui reg lwage $xvars
predict rwage , residuals

quiet unique key_l
if r(unique)>1{
	qui reg lwage $xvars , a(key_l)
	predict arwage , residuals
	}
else gen arwage=1


xi: qui reg lwage $few_x
predict fwage , residuals

quiet unique key_l
if r(unique)>1{
	qui reg lwage $few_x , a(key_l)
	predict afwage , residuals
	}
else gen afwage=1



gen samples = year<2008 & nace<"L"
replace samples = 1 if year>2008 & !inlist(nace,"XO","O","XD","XL","XR")

gen swage = lwage if samples==1

xi: qui reg lwage $xvars if samples==1
predict rswage if samples==1 , residuals

quiet unique key_l
if r(unique)>1{
	xi: qui reg lwage $xvars if samples==1, a(key_l)
	predict arswage if samples==1, residuals
	}
else gen arswage=1


egen grouper = group( fem age educ size2 part nnace pub ten part indef)
egen elwage = mean(lwage), by(group)
gen nprwage = lwage - elwage

** Measures of dispersion in characteristics
*-------------------------------------------------
own_ineq grouper, by(`isco2d') gend(disp_2d) genm(m2_2d) genev(even_2d) gens(simps_2d)
own_ineq grouper, by(`isco3d') gend(disp_3d) genm(m2_3d) genev(even_3d) gens(simps_3d)

*----------------------------------------------------------------------------*
*		 Database characteristics
 
capture drop t?0
qui sum hwage,d

gen t90 = `r(p90)'
gen t50 = `r(p50)'
gen t10 = `r(p10)'

preserve
collapse 	(mean) fem prime_age high_edu hwage large year part pub no_col ten indef overt is3d_ses= `isco3d' (sum) w weight  ///
			(p90) p90 = hwage r90 = rwage ar90 = arwage rs90 = rswage ars90 = arswa np90 = nprwage s90 = swage f90 = fwage af90 = afwage ///
			(p50) p50 = hwage r50 = rwage ar50 = arwage rs50 = rswage ars50 = arswa np50 = nprwage s50 = swage f50 = fwage af50 = afwage /// 
			(p10) p10 = hwage r10 = rwage ar10 = arwage	rs10 = rswage ars10 = arswa np10 = nprwage s10 = swage f10 = fwage af10 = afwage /// 
			(first) disp_2d m2_2d even_2d simps_2d country N_obs t90 t50 t10 hh2 s1_s10, by(`isco2d')

			
save "$eu_ses\mean2d_`i'", replace

restore 

collapse 	(mean) fem prime_age high_edu hwage large year part pub no_col ten  indef overt (sum) w weight  ///
			(p90) p90 = hwage r90 = rwage ar90 = arwage rs90 = rswage ars90 = arswa np90 = nprwage s90 = swage f90 = fwage af90 = afwage ///
			(p50) p50 = hwage r50 = rwage ar50 = arwage rs50 = rswage ars50 = arswa np50 = nprwage s50 = swage f50 = fwage af50 = afwage /// 
			(p10) p10 = hwage r10 = rwage ar10 = arwage	rs10 = rswage ars10 = arswa np10 = nprwage s10 = swage f10 = fwage af10 = afwage /// 
			(first) disp_3d m2_3d even_3d simps_3d country N_obs t90 t50 t10 hh3, by(`isco3d')
save "$eu_ses\mean3d_`i'", replace




}




foreach d in 2 3{
clear

local nsets: word count $datas
	forvalues i = 1/`nsets'{
	append using "$eu_ses\mean`d'd_`i'", force
	erase "$eu_ses\mean`d'd_`i'.dta"
	}
 
drop if hh==.
replace country="EL" if country =="GR"

global name0 country
quiet include "$do_ineq\country codes"

drop if inlist(c_code, "LUX" ,"CYP" ,"MLT")

** Measures of wage dispersion 

gen lwage =log(hwage) 

gen l9010 = log(p90/p10) 
gen l9050 = log(p90/p50) 
gen l5010 = log(p50/p10) 

encode c_code, gen(cn)
 
foreach pre in r ar rs ars s np f af{ 
gen `pre'9010 = abs(`pre'90-`pre'10)
gen `pre'9050 = abs(`pre'90-`pre'50) 
gen `pre'5010 = abs(`pre'50-`pre'10) 
}


** Country variances

foreach var in prime fem lar high_edu part pub no_col ten indef overt{
gen `var'2 = `var' *(1-`var')
}

egen isco`d'd =rowmax(isco88_`d'd isco08_`d'd)
label data "Avg of main charac by country and occupation (`d' digits)" 			
save "$eu_ses\avg`d'd", replace

}


** N of subdivisions (akin to an occupation FE)

foreach d in  2 3  {
import excel "$eu_ses\isco88_isco08.xlsx", sheet("Arkusz1") cellrange(B1:C674) firstrow clear

ren *, lower

foreach var in isco88 isco08{

preserve 
keep `var'
duplicates drop `var', force
gen isco`d'd = substr(`var',1,`d')
egen n_subd = count(1), by(isco`d'd) 
  
drop `var'
duplicates drop isco`d'd, force

expand 2 , gen(year)
if "`var'" == "isco88" recode year (0=2002) (1=2006)
if "`var'" == "isco08" recode year (0=2010) (1=2014)

tempfile `var'_ns
save ``var'_ns', replace
restore  
}  

clear 
use `isco08_ns'
append using `isco88_ns'

drop if missing(isco`d'd , year)
destring isco`d'd, replace
merge 1:m year isco`d'd using "$eu_ses\intermediate\avg`d'd", gen(m_nsubd)
save "$eu_ses\intermediate\avg`d'd", replace
clear
}
