*-------------------------------------------------------------------*
*		Calculates change in occupation size in last n years		*
*-------------------------------------------------------------------*
 
cd "$eu_lfs"
 
* 1) Collect data on occupation size in years 
	* 1992,1997,2002 
	* 1996,2001,2006
	* More recent data were not available (ISCO 08 was introduced in LFS 2011)
	
foreach year in  1992  1997 2002 1996 2001 2006{
	
	local i =1
	local k =1
	local files : dir "" file "*_`year'*"
	
	foreach f in `files'{
	
		use `f', clear
		
		di as error "`f'"
		capture destring is883d, replace force

		unique is883d if !missing(is883d)
		
		if `r(unique)'<5 {
			di "We are not using `f'"
			continue
			}
		
		drop if is883d==999 | is883d==99
		gen is882d = floor(is883d/10)
		gen n_`year' = 1 

		
		** For 3 digits data
		 
		egen sd_aux = sd(is883d), by(is882d)
		sum sd_aux
		if `r(mean)' !=0 {
			preserve 
			collapse (sum) n_`year' (first) year country [iw=weight], by(is883d)
		
			quiet sum n_`year'
			replace n_`year' = n_`year'/(`r(mean)'*`r(N)')
			
			tempfile part`k'_3d
			save `part`k'_3d' , replace
			
			restore
			local ++k
		}
		
		
		** For 2 digits data
		
		collapse (sum) n_`year' (first) year country [iw=weight], by(is882d)
	
		quiet sum n_`year'
		replace n_`year' = n_`year'/(`r(mean)'*`r(N)')
		
		tempfile part`i'
		save `part`i'', replace
		
		local ++i
		}

		
	local j = `i'-1
	clear
	forvalues i = 1/`j'{
		append using `part`i''
		}

	save "$lfs_proc\occs_`year'", replace
	
	local j = `k'-1
	clear
	forvalues i = 1/`j'{
		append using `part`i'_3d'
		}
	
	save "$lfs_proc\occs_3d_`year'", replace
	
	}
	

* 2-a) Putting the databases together (2 digits)

cd	"$lfs_proc"

use occs_1992, clear
foreach yy in 1997 2002 {
merge 1:1 country  is882d using occs_`yy', gen(m_`yy')
}
gen year_final = 2002
tempfile part1
save `part1', replace

use occs_1996, clear
foreach yy in 2001 2006 {
merge 1:1 country   is882d using occs_`yy', gen(m_`yy')
}
gen year_final = 2006
append using `part1'

gen change_5 = (n_2002 - n_1997) 
replace change_5 = n_2006- n_2001 if change_5==.

gen change_10 = (n_2002 - n_1992) 
replace change_10 = n_2006- n_1996 if change_10==.

keep change* country is882d year_final
rename (year_final is882d) (year isco2d)

global name0 country
quiet include "$do_ineq\country codes"

save "$lfs_proc\occ_change_2d_2018" , replace


* 2-b) Putting the databases together (3 digits)

cd	"$lfs_proc"

use occs_3d_1992, clear
foreach yy in 1997 2002 {
merge 1:1 country  is883d using occs_3d_`yy', gen(m_`yy')
}
gen year_final = 2002
tempfile part1
save `part1', replace

use occs_3d_1996, clear
foreach yy in 2001 2006 {
merge 1:1 country   is883d using occs_3d_`yy', gen(m_`yy')
}
gen year_final = 2006
append using `part1'

gen change_5 = (n_2002 - n_1997) 
replace change_5 = n_2006- n_2001 if change_5==.

gen change_10 = (n_2002 - n_1992) 
replace change_10 = n_2006- n_1996 if change_10==.

keep change* country is883d year_final
rename (year_final is883d) (year isco3d)

global name0 country
quiet include "$do_ineq\country codes"

save "$lfs_proc\occ_change_3d", replace
