*-----------------------------------------------*
*		Create task measures from O*NET			*
*-----------------------------------------------*

* Task files should be placed in a sub-folder of O*NET
* The folder name should be [year]_ONET 


cd "$onet"

** Merging the files
*----------------------------------------------
tempfile abilities skills workcont workact

foreach y1 in  2004 2014 {

capture cd "`y1'_ONET"		// <- Please secure that the path is correct

clear
if `y1' ==2004 insheet using "Ability.txt"
if `y1' ==2014 insheet using "Abilities.txt"
save `abilities', replace

clear
insheet using "Skills.txt"
save `skills', replace

clear
if `y1' ==2004 insheet using "WorkContext.txt"
if `y1' ==2014 insheet using "Work Context.txt"
save `workcont', replace

clear
if `y1' ==2004 insheet using  "WorkActivity.txt"
if `y1' ==2014 insheet using  "Work Activities.txt"
save `workact', replace

clear
append using "`abilities'"
append using "`skills'"	
append using "`workcont'"
append using "`workact'"

cd ..
label data "O*NET data merged for the year `y1'"
save merged_`y1', replace

clear

}

** Cleaning the databases 
*---------------------------------------------

foreach y1 in  2004 2014{
use merged_`y1', clear

keep if scaleid=="IM" | scaleid=="CX"
capture drop notrelevant recommendsuppress

rename domainsource source
replace source="Legacy Analyst" if source=="Analyst"

rename datavalue score

//Destring what is possible
foreach var of varlist _all {
	cap noisily destring `var', dpcomma replace ignore("n/a")
}


// Dates -- Might be useful at some point
gen year=substr(string(date), -4, . )
gen month=int(date/10000)
drop date
destring year, replace
gen date=ym(year, month)
format %tm date

sort onetsoccode elementid date



collapse (mean) score (last) elementname, by(onetsoccode elementid)

replace elementid=subinstr(elementid, ".", "", 5) 


/* Reshape so ONET-SOC code has one observation with all task measures */
cap drop elementname
reshape wide score, i(onetsoccode) j(elementid) string

renpfix score t_

//Following Autor
/* Reverse the scale of the structured v. unstructured work measure */
gen t_4C3b8_rev=6-t_4C3b8
/* Reverse the scale of the measures that comprise the offshorability measure */
gen t_4C1a2l_rev=6-t_4C1a2l
gen t_4C2a3_rev=6-t_4C2a3
/* Reverse scale of work activities that comprise offshorability measure */
foreach var in t_4A4a4 t_4A4a5 t_4A4a8 t_4A4b5 t_4A1b2 t_4A3a2 t_4A3a3 t_4A3a4 t_4A3b4 t_4A3b5 {
	gen `var'_rev=6-`var'
}

keep onetsoccode t_4A2a4 t_4A2b2 t_4A4a1 t_4A4a4 t_4A4b4 t_4A4b5 t_4C3b7 t_4C3b4 t_4C3b8_rev t_4C3d3 t_4A3a3 t_4C2d1i t_4A3a4 t_4C2d1g t_1A2a2 t_1A1f1 t_2B1a t_4C1a2l_rev t_4A4a5_rev t_4A4a8_rev t_4A1b2_rev t_4A3a2_rev t_4A3b4_rev t_4A3b5_rev
sort onetsoccode
compress

label data "O*NET data merged & cleaned for the year `y1'"

save merged_`y1',   replace
}
 
 
 
 
** Making the cross walks -- Different for various years 
*-------------------------------------------------------

* O*NET changed the classification in 2010! 
 
use merged_2004 , clear
rename onetsoccode onetsoc00

replace onetsoc00=subinstr(onetsoc00, "-", "", 1) 
destring onetsoc00 , gen(soc00)
replace soc00 = int(soc00)

* ISCO 2008
preserve  

collapse (mean) t_* (first) onetsoc00 , by(soc00)

joinby soc00 using "$crosswalks\soc00_soc10"
collapse (mean) t_* (first)onetsoc00 , by(soc10)

joinby soc10 using "$crosswalks\soc10_isco08"
collapse (mean) t_* , by(isco08)

destring isco08, replace
gen isco3d = floor(isco08/10)
 
collapse (mean) t_* , by(isco3d)
label data "task content of jobs: isco08 3 digit data"
save "tasks08_2004_3d.dta", replace

gen isco2d = floor(isco3d/10)
collapse (mean) t_* , by(isco2d)
label data "task content of jobs: isco08 2 digit data"
save "tasks08_2004_2d.dta", replace

restore


* ISCO 1988
collapse (mean) t_* (first)onetsoc00 , by(soc00)
joinby soc00 using "$crosswalks\isco88_soc00"

destring isco88, replace
gen isco3d = floor(isco88/10)


collapse (mean) t_* , by(isco3d)
label data "task content of jobs: isco88 3 digit data"
save "tasks88_2004_3d.dta", replace


gen is882d = floor(isco3d/10)
collapse (mean) t_* , by(isco2d)
label data "task content of jobs: isco88 2 digit data"
save "tasks88_2004_2d.dta", replace

*-------------------------------------------------------------*

use merged_2014

rename onetsoccode onetsoc10
replace onetsoc10=subinstr(onetsoc10, "-", "", 1) 
destring onetsoc10 , gen(soc10)
replace soc10 = int(soc10)

* ISCO 2008
preserve
collapse (mean) t_* (first)onetsoc10 , by(soc10)

joinby soc10 using "$crosswalks\soc10_isco08"
collapse (mean) t_* , by(isco08)

destring isco08, replace
gen isco3d = floor(isco08/10)
 
collapse (mean) t_* , by(isco3d)
label data "task content of jobs: isco08 3 digit data"
save "tasks08_2014_3d.dta", replace

gen isco2d = floor(isco3d/10)
collapse (mean) t_* , by(isco2d)
label data "task content of jobs: isco08 2 digit data"
save "tasks08_2014_2d.dta", replace

restore


* ISCO 1988
preserve
collapse (mean) t_* (first)onetsoc10 , by(soc10)

joinby soc10 using "$crosswalks\soc00_soc10"
collapse (mean) t_* (first)onetsoc10 , by(soc00)
 
joinby soc00 using "$crosswalks\isco88_soc00"

destring isco88, replace
gen isoc3d = floor(isco88/10)

collapse (mean) t_* , by(isco3d)
label data "task content of jobs: isco88 3 digit data"
save "tasks88_2014_3d.dta", replace


gen isco2d = floor(isco3d/10)
collapse (mean) t_* , by(isco2d)
label data "task content of jobs: isco88 2 digit data"
save "tasks88_2014_2d.dta", replace

clear
