*-------------------------------------------*
*		Merging all the databases			*
*-------------------------------------------*



** 2 Digit ISCO codes
*--------------------------------------

use "$eu_ses\avg2d", clear

* Put the data together
merge 1:1 c_code year isco2d using "$onet\tasks_ready_2d" , gen(m_tasks)
merge 1:1 c_code year isco2d using "$lfs_proc\occ_change_2d_2018", gen(m_occs)
merge m:1 c_code year using "$dta\macro_eu", gen(m_eu)


** Reviewing the missing values
browse c_code year if m_eu==2
drop if m_eu==2  // countries and years without SES
drop if c_code==""


browse c_code country year isco2d m_tasks if m_tasks==2
* == : Germany 2002 (no ses in that year)! 
* == : Greece 2014 (No SES) and Hungary 2014 (10 less occupations than the rest)
* == : occupations around 61-63 & 95+ --> very minor groups, not an issue
* == : Belgium only reports some occupations in 2002

drop if inlist(c_code,"AUT", "CHE", "DNK","HRV","IRL","ISL","MLT","SVN")
drop if c_code=="DEU" & year ==2002
drop if c_code=="GRC" & year ==2014
drop if m_tasks==2  

browse c_code country year isco2d m_tasks if m_tasks==1
* == : GRC with 16 ``fake'' occupation codes
* == : ROM with no tasks  in 2002 (imputing from 2006)
drop if  c_code =="GRC" & year ==2006 & m_tasks==1

* Correcting ROM 2002
foreach var of varlist nr_cog* nr_pers* r_cog* r_man* nr_man* rti* {
	capture drop aux
quiet {
	egen aux = min(`var') if c_code=="ROM" & inlist(year,2002,2006), by(isco88_2d)  
	replace `var' = aux if c_code=="ROM" & year ==2002
	}
}
capture drop aux

** Correcting for other missing tasks (57 replacements)
gen isco1d = floor(isco2d/10)
foreach var of varlist nr_cog* nr_pers* r_cog* r_man* nr_man* rti*{
egen aux = mean(`var') , by(c_code year isco1d)
replace `var' = aux if `var' ==.
drop aux
}

browse c_code country year isco2d  if m_occs==2
* ==> Only occupations at 1 digit disguised as 2 (e.g. 10)
drop if mod(isco2d,10) ==0 
drop if isco2d ==. | isco2d<10

** Removing not-needed variables
drop *_label 
drop merge*

** Correcting for possible missings
foreach var in fem ten no_col pub part indef overt {
egen mean_`var' = mean(`var'), by(c_code year)
replace `var' =. if mean_`var' ==0
replace `var'2= . if `var' == .
drop mean_`var'
}


egen mean_ses = mean(is3d_ses), by(c_code year)
gen mis_lfs = mod(isco_3d,10)==0 
egen mis_all_lfs = max(mis_lfs) ,  by(c_code year)
replace is3d_ses = . if mean_ses==0 |  mis_all_lfs==1 
drop mean_ses mis_lfs mis_all_lfs
 
gen miss_occ_u =unemp_occ_2d ==.
egen mean_miss = mean(miss_occ_u), by(c_code year)
replace miss_occ_u  = . if mean_miss ==1
drop mean_miss

gen any_missing = missing( ten, no_col, pub, part, indef, overt, miss_occ_u, n_subd)

gen samples = !missing( ten, no_col, pub, part, indef, overt, miss_occ_u, n_subd,unemp_occ_2d)

gen out_s= 0
replace out_s = 1 if year ==2002 & inlist(c_code,"BEL", "EST", "FIN", "FRA", "GRC", "HUN")
replace out_s = 1 if year ==2002 & inlist(c_code, "ITA", "LVA","NOR","PRT","ESP", "SWE")
replace out_s = 1 if year ==2006 & inlist(c_code, "BEL", "DEU","FRA","GRC","ITA", "NOR","PRT","ESP")
replace out_s = 1 if year ==2010 & inlist(c_code,"BEL","DEU","ITA","NOR", "PRT")
replace out_s = 1 if year ==2014 & inlist(c_code,"BEL","DEU","NOR", "PRT")

** Labels
capture program drop labeller
program labeller

label var change_5  "Change"
label var change_10 "Change (10 yrs)"
label var emp_rate   "Employment rate"
label var unemp_rate "Unemployment rate"
label var ch_gdp_yty "GDP growth"
end program
label var s1_s10 "S1/S10"
labeller



save "$ses_proc\final2d", replace
 

*------------------------------------------------------------------------------*

** 3 Digit ISCO codes
*--------------------------------------------

use "$eu_ses\avg3d", clear

merge 1:1 c_code year isco3d using "$onet\ready\tasks_new_ready_3d" , gen(m_tasks)
merge 1:1 c_code year isco3d using "$eu_lfs\intermediate\occ_change_3d_2018", gen(m_occs)
merge m:1 c_code year using "$dta\macro_iea_2018", gen(m_iea)

tab c_code year if m_tasks==1
** Only 2 digits data on tasks (POL, BGR) and no LFS (MLT)
** Several countries 2 digit codes which represent a few obs (CZE, FRA, etc.) mostly military
drop if inlist(c_code,"POL","BGR","MLT")
drop if isco3d<100 

tab isco3d year if m_tasks==1
* very spread. 810 and 910 stand out (paper maker and vehicle cleaners)

tab c_code year if m_tasks==2
** All countries that have only 2 digits in SES
drop if inlist(c_code, "AUT", "BEL", "CHE", "DEU", "DNK","ESP")
drop if inlist(c_code, "FIN", "HRV", "ISL", "IRL", "NLD","PRT")
** Countries with a few years missing
drop if c_code=="GRC" & year !=2002
drop if c_code=="ITA" & year !=2014
drop if c_code=="NOR" & year !=2006
drop if c_code=="ROM" & year !=2002
drop if c_code=="SWE" & year >2006
drop if c_code=="HUN" & year >2006
drop if c_code=="FRA" & year ==2002

tab isco3d year if m_tasks==2
* very spread. A few codes stand out 220's, 330's, 520's, 610's, 950's
* Not includes in EU-SES
* 950's street and related vendors
* 610's agricultural workers
* 520's street and market salespersons
* 330's teachers
* 220's Health specialists

drop if m_tasks!=3

tab year if m_occs==1
* Only years 2002-2006 are matched. THere the match is perfect (it is same data as previous)

labeller
drop *_label 
drop merge*


** Correcting for possible missings
foreach var in fem ten no_col pub part indef overt {
egen mean_`var' = mean(`var'), by(c_code year)
replace `var' =. if mean_`var' ==0
replace `var'2= . if `var' == .
drop mean_`var'
}

gen miss_occ_u =unemp_occ_3d ==.
egen mean_miss = mean(miss_occ_u), by(c_code year)
replace miss_occ_u  = . if mean_miss ==1
drop mean_miss

gen any_missing = missing( ten, no_col, pub, part, indef, overt, miss_occ_u, n_subd)

gen samples = !missing(ten, no_col, pub, part, indef, overt, miss_occ_u, n_subd, unemp_occ_3d)



gen out_s= 0
replace out_s = 1 if year ==2002 & inlist(c_code,"BEL", "EST", "FIN", "FRA", "GRC", "HUN")
replace out_s = 1 if year ==2002 & inlist(c_code, "ITA", "LVA","NOR","PRT","ESP", "SWE")
replace out_s = 1 if year ==2006 & inlist(c_code, "BEL", "DEU","FRA","GRC","ITA", "NOR","PRT","ESP")
replace out_s = 1 if year ==2010 & inlist(c_code,"BEL","DEU","ITA","NOR", "PRT")
replace out_s = 1 if year ==2014 & inlist(c_code,"BEL","DEU","NOR", "PRT")

save "$ses_proc\final3d", replace
