/*=================================================================
				Descriptive statistics
=================================================================*/


use "$ses_proc\final2d", replace



* Sample characteristics
* -----------------------------------------
capture drop f_cn
bys country year: gen f_cn = _n==1

capture drop tot_year
egen tot_year = sum(w), by(year)

 
mat descs =J(5,5,.)
local i =1
forvalues y = 2002(4)2014{

qui sum tot_year if year ==`y'  
mat descs[1,`i'] = `r(mean)'

quiet sum w if year==`y',d
mat descs[3,`i'] = `r(mean)'
mat descs[4,`i'] = `r(p50)'
mat descs[5,`i'] = `r(p10)'

mat descs[2,`i'] = `r(N)'

local ++i
}

mat descs[1,`i'] = descs[1,1]+descs[1,2]+descs[1,3]+descs[1,4]

quiet sum w ,d
mat descs[3,`i'] = `r(mean)'
mat descs[4,`i'] = `r(p50)'
mat descs[5,`i'] = `r(p10)'
mat descs[2,`i'] = `r(N)'

mat colnames descs ="2002" "2006" "2010" "2014" "Total"
mat rownames descs = "N workers" "N cells (oct)" "Avg  N$ _{oct}$" ///
					"Median  N$ _{oct}$" "P(10) N$ _{oct}$"  
				
estout matrix(descs, fmt(0)) using "$logs\tab_00_descs.tex", sty(tex) mlabels(none)  replace  ///
	prehead ("\begin{tabular}{@{\extracolsep{4pt}}l*{5}{c}}" "\hline \hline"  "Year") ///
	posthead("\hline") postfoot( \hline \hline \end{tabular})


* Evolution of within occupation wage dispersion
* -------------------------------------------------------------


foreach st in af l{
	foreach nd in 9010 9050 5010{
		tabstat `st'`nd' , by(year)  save stat(mean sd)
		mat `st'`nd' = r(Stat1)',r(Stat2)',r(Stat3)',r(Stat4)'
	}
} 

mat part1 = ar9010 \ ar9050 \ar5010	
mat part2 = l9010 \ l9050 \l5010		

mat rownames part1 = "log(p90/p10)" "log(p90/p50)" "log(p50/p10)"
mat rownames part2 = "log(p90/p10)" "log(p90/p50)" "log(p50/p10)"

estout matrix(part1, fmt(3 2 3 2 3 2 3 2 )) using "$logs\tab_00_descsb.tex" , ///
	sty(tex) mlabels(none) collabels(none)  replace  ///
	prehead ("\begin{tabular}{@{\extracolsep{4pt}}l*{8}{c}}" "\hline \hline" ///
	"Year & \multicolumn{2}{c}{2002} & \multicolumn{2}{c}{2006} & \multicolumn{2}{c}{2010}" ///
	" & \multicolumn{2}{c}{2014} \\" ///
	"& Mean & SD &  Mean & SD &  Mean & SD &  Mean & SD \\ \hline  \\[-.15cm]  " ///
	"\multicolumn{5}{l}{Adjusted wages} \\ ")
	
estout matrix(part2, fmt(3 2 3 2 3 2 3 2 )) using "$logs\tab_00_descsb.tex",  append sty(tex) mlabels(none) collabels(none) ///
	prehead ("[.2cm]" "\multicolumn{5}{l}{Raw wages} \\  ") postfoot( \hline \hline \end{tabular})
	
 
	
*	RTI and inequality: a visual inspection
*------------------------------------------------------------------	
 
forvalues y  = 2002(4)2014{
spearman f9010 rti_03 if year==`y'

local sp = round(`r(rho)',0.001)
local pv = round(`r(p)',0.01)

scatter l9010 rti_03 if year==`y' & l9010<3 ,  nodraw name(gp`y', replace)  mcolor(%30) ///
	 ylabel(0(1)3, angle(horizontal)) scheme(s1mono) ytitle("log(p90/p10)") ///
	text(2.5 0.75 "{&rho}: `sp' (p-val: 0.00)", size(small)) title(`y') 
}
graph combine gp2002 gp2006 gp2010 gp2014 , scheme(s1mono)
graph export "$graphs\correl_rti.png", as(png) replace

*----------------------------------------------------------------------------*



*   Descriptive statistics (x's) -- Appendix
*--------------------------------------------------------------------------

cd "$do_ineq"
capture do paths

use "$eu_ses\intermediate\final2d_2019", replace


label var fem  	"\% female" 
label var prime_age  "\% age $ < $ 60" 
label var high_edu 	"\% tertiary studies" 
label var large "\% in large firms" 
label var part 	"\% part-time work"
label var pub  	"\% in SOE - public sector"
label var no_col "\% not collective agreement"
label var ten    "\% tenure < 5 years"
label var indef "\% with open-ended contracts"
label var overt "\% with overtime"
label var hh2	"HHI (indus)"
label var simps	"HHI (X)"
label var unemp_occ_2d	"Unemp. rate $ _{oct} $ "

capture file close tab_desc
capture file open tab_desc using "$logs\tab__a_desc.tex" , write replace
local files tab_desc
file write `files' " \begin{tabular}{l  c c c c c c c c}" _n "\hline \hline" _n
file write `files' " Variable  & \multicolumn{2}{c}{2002} & \multicolumn{2}{c}{2006} & \multicolumn{2}{c}{2010} & \multicolumn{2}{c}{2014} \\ " _n
file write `files' " & Mean & Missing& Mean & Missing& Mean & Missing& Mean & Missing \\ \hline" _n


foreach var in hh simps unemp_occ_2d fem prime_age high_edu large part pub no_col ten indef overt {


if "`var'" == "hh" {
file write `files' "\multicolumn{9}{l}{Market characteristics} \\[0.2cm] " _n 
}

if "`var'" == "fem" {
file write `files' "[0.2cm]" _n
file write `files' 	"\multicolumn{9}{l}{Worker and job characteristics} \\ " _n 
}

local name : var label `var'
file write `files' " `name'" 


forvalues y = 2002(4)2014{	
quiet sum `var' if year==`y'
local  mn = floor(`r(mean)'*100)/100

quiet count if missing(`var') & year==`y'
local ms = `r(N)'

file write `files' " & `mn' & `ms'" 
}
file write `files' " \\ " _n 

}

file write `files'  "\hline \hline" _n "\end{tabular}"
file close `files'

