*-------------------------------------------*
*			Robustness checks				*
*-------------------------------------------*


use "$ses_proc\final2d", replace


** Globals
*----------------------------------------------

global stderr "vce(robust)"
global all_x  "prime_  fem high_edu ten hwage larg part pub  indef overt  " 
global x_ar	  "unemp_occ_2d hh n_subd simps_2d"
global all_x2 "$all_x $x_ar"
global tasks  "nr_cog_03 nr_pers_03 r_cog_03 r_man_03 nr_man_03"




**		One country at a time
*-------------------------------------------

* Excluding / including one country at a time

levelsof c_code , local(cc)

local if1 
foreach c in `cc'{
local i = 0

foreach x in 1 2{
local if1 if c_code=="`c'"
local if2 if c_code!="`c'"

foreach var in 9010 9050 5010{
local ++i

reg f`var' rti_03 i.year `if`x''
eststo `c'`i'
}
}
}

local xy	  "inc_exc"
local part	   1
local file_n  "$logs\tab__a_incl.tex"
quiet include "$do_ineq\fancy_tab"

est drop _all
forvalues y = 2002(4)2014{
local i = 0

foreach x in 1 2{
local if1 if year ==`y'
local if2 if year !=`y'


foreach var in 9010 9050 5010{
local ++i

reg f`var' rti_03 i.cn  `if`x''
eststo e`y'`i' 
}
}
}

local xy	  "inc_exc"
local part	   2
local file_n  "$logs\tab__a_incl.tex"
include 	  "$do_ineq\fancy_tab"

est drop _all


** 			RTI -square
*-------------------------------------------
 
 
foreach var in 9010 9050 5010{

quiet reg ar`var'  c.rti_03##c.rti_03##c.rti_03  i.year i.cn if samples==1 & c_code!="FIN" ,  $stderr
estimates store l`var'1

quiet reg ar`var' c.rti_03##c.rti_03##c.rti_03 $x_ar  i.year i.cn if samples==1 & c_code!="FIN",  $stderr
estimates store l`var'2

reg  l`var'  c.rti_03##c.rti_03##c.rti_03 i.year i.cn if samples==1, $stderr
estimates store l`var'0

reg  l`var'  c.rti_03##c.rti_03##c.rti_03 $all_x i.year i.cn if samples==1, $stderr
estimates store l`var'3

quiet reg  l`var'  c.rti_03##c.rti_03##c.rti_03 $all_x2 i.year i.cn if samples==1,  $stderr
estimates store l`var'4

}


local r9050 l90501 l90502 l90503 l90504   
local r9010 l90101 l90102 l90103 l90104   
local r5010 l50101 l50102 l50103 l50104 

local xy 	  "rti2"
local file_n  "$logs\tab__a_rti2.tex" 
include 	  "$do_ineq\fancy_tab"
est drop _all

preserve
keep if samples==1

quiet reg ar9010 c.rti_03##c.rti_03##c.rti_03 $x_ar  i.year i.cn if samples==1 & c_code!="FIN",  $stderr
margins , at(rti=(-2.5(0.125)2.5)) post
est store mod1

quiet reg ar9010 c.rti_03 $x_ar  i.year i.cn if samples==1 & c_code!="FIN",  $stderr
margins , at(rti=(-2.5(0.125)2.5)) post
est store mod2 

coefplot mod1 mod2, vertical legend( order(4 "Linear" 2 "Cubic polynomial") region(lcolor(white))) ///
        ytitle("Fitted values") ylab(,ang(horizontal))  ///
		xtitle("RTI")  xlab( 1 "-2.5" 9 "-1.5" 21 "0" 33 "1.5" 41 "2.5") ///
		scheme(s2mono) title(log(p90/p10)) name(g9010, replace)  $area	 xsize(7)

	graph export "$graphs\comparison.eps", as(eps) replace
restore

** 			Winners
*-----------------------------------------------


foreach var in 9010 9050 5010{

foreach l in  l r {
reg  `l'`var'   rti_03   s1_s10 i.year i.cn if s1_s10 <20 & samples==1,  $stderr
estimates store `l'`var'1 
}

reg  ar`var'   rti_03   s1_s10 i.year i.cn if s1_s10 <20 & c_code!="FIN" & samples==1,  $stderr
estimates store ar`var'1 

reg  l`var'   rti_03   s1_s10 $all_x i.year i.cn  if s1_s10 <20 & samples==1,  $stderr
estimates store l`var'2 

reg  l`var'   rti_03   s1_s10 $all_x2 i.year i.cn  if s1_s10 <20 & samples==1,  $stderr
estimates store l`var'3 

reg  ar`var'   rti_03   s1_s10 $x_ar  i.year i.cn if s1_s10 <20 & c_code!="FIN" & samples==1,  $stderr
estimates store ar`var'2  
}

local w9010 ar90101 ar90102 l90102 l90103 
local w9050 ar90501 ar90502 l90502 l90503 
local w5010 ar50101 ar50102 l50102 l50103

local xy 	 "winners"
local file_n "$logs\\tab__a_win.tex"
include 	 "$do_ineq\\fancy_tab"
est drop _all


**		Macro variables
*---------------------------------------------------- 

foreach var in 9010 9050 5010{

quiet reg  l`var'  rti_03 $all_x2 i.year i.cn emp_rate unemp_rate ch_gdp_yty if samples==1 , $stderr
estimates store l`var'4

reg  l`var'  rti_03  $all_x2 year##cn if samples==1 , $stderr
estimates store l`var'5


quiet reg  ar`var'  rti_03 $x_ar i.year i.cn emp_rate unemp_rate ch_gdp_yty if samples==1 & c_code!="FIN", $stderr
estimates store ar`var'4

reg  ar`var'  rti_03  $x_ar year##cn if samples==1 & c_code!="FIN", $stderr
estimates store ar`var'5

}

local m9010 ar90104 ar90105 l90104 l90105   
local m9050 ar90504 ar90505 l90504 l90505 
local m5010 ar50104 ar50105 l50104 l50105 

local xy = "Macro"
local file_n "$logs\tab__a_macro.tex"
quiet include "$do_ineq\\fancy_tab" 
est drop _all


*		Other specification tests
*------------------------------------------------*


global few_x prime_age fem large high_edu hwage overt 
global sq prime2 fem2 lar2 high_edu2 part2 pub2  simps indef2 overt2 ten2


foreach var in 9010 9050 5010{

reg  l`var'  c.rti_03 $few_x $x_ar i.year i.cn   , $stderr
est stor  r`var'0

reg  af`var'  c.rti_03 $x_ar i.year i.cn if  c_code!="FIN" , $stderr
est stor  a`var'0



reg  s`var'  c.rti_03 $all_x2 i.year i.cn , $stderr
estimates store r`var'1

reg  l`var'  rti_03 $all_x2 i.year i.cn if out_s!=1  , $stderr
estimates store r`var'2


reg  ars`var'  rti_03 $x_ar i.year i.cn if c_code!="FIN" , $stderr
estimates store a`var'1

reg  ar`var'  rti_03 $x_ar i.year i.cn if out_s!=1 &  c_code!="FIN" , $stderr
estimates store a`var'2

reg  np`var'  rti_03 i.year i.cn  $x_ar if samples==1 , $stderr
est stor  a`var'6

reg  r`var'  rti_03 i.year i.cn  $x_ar if samples==1 , $stderr
est stor  a`var'6b

reg  l`var'  rti_03 i.year i.cn  $all_x $x_ar $sq if samples==1, $stderr
est stor  r`var'7
  
reg  ar`var'  rti_03 i.year i.cn $x_ar $sq if samples==1 & c_code!="FIN" , $stderr
est stor  a`var'7


reg  l`var'  rti_03 $all_x $x_ar i.year i.cn if w>500 , $stderr
est stor  r`var'8


reg  ar`var'  rti_03 $all_x $x_ar i.year i.cn if samples==1 & c_code!="FIN"  & w>500 , $stderr
est stor  a`var'8
 
}

capture ren (rti_14 rti_03) (rti_03 rti_14)
foreach var in 9010 9050 5010{

reg  l`var'  c.rti_03 $all_x2 i.year i.cn , $stderr
est stor  r`var'3

reg  ar`var'  c.rti_03 $x_ar i.year i.cn if c_code!="FIN"  & samples==1 , $stderr
est stor  a`var'3


}
capture ren (rti_14 rti_03) (rti_03 rti_14)



foreach v in 9010 9050 5010{
local l`v' a`v'3 r`v'3 a`v'7 r`v'7 a`v'6 a`v'6b a`v'1 r`v'1 a`v'2 r`v'2 a`v'0 r`v'0 a`v'8 r`v'8
}

local xy 	  "misc"
local file_n  "$logs\tab__a_misc.tex" 
include 	  "$do_ineq\fancy_tab"
est drop _all


