*-------------------------------------------*
*			Robustness checks				*
*-------------------------------------------*
 
use "$ses_proc\final3d", replace


* Creating a combined database
*-------------------------------------------------
append  using "$eu_ses\intermediate\final2d", gen(w_2d)
egen has_3d = min(w_2d), by(c_code year)
replace has_3d = 1-has_3d


** Globals
*---------------------------------------------------------------
global stderr "vce(robust)"
global all_3d  "prime_ fem larg high_edu hwage part pub unemp_occ_3d indef overt  " 
global x_3d	   "unemp_occ_3d hh3 n_subd simps_3d"
global all_3d2 "$all_3d $x_3d"

global tasks   "nr_cog_03 nr_pers_03 r_cog_03 r_man_03 nr_man_03"

global all_x  "prime_ fem larg high_edu hwage part pub indef overt  " 
global x_ar	  "unemp_occ_2d hh2 n_subd simps_2d"
global all_x2 "$all_x $x_ar"



**    Main specification
*-------------------------------------------

 foreach var in 9010 9050 5010{

reg  ar`var'  rti_03  i.year i.cn if c_code!="FIN" & w_2d==0 & samples==1, $stderr
estimates store l`var'1

reg  ar`var'  rti_03  $x_3d i.year i.cn  if c_code!="FIN" & samples==1& w_2d==0,  $stderr
estimates store l`var'2

reg  ar`var' rti_03  $x_ar i.year i.cn  if c_code!="FIN" & samples==1  & has_3d==1 & w_2d==1,  $stderr
estimates store l`var'3


reg  l`var'  rti_03  $all_3d  i.year i.cn  if w_2d==0  & samples==1, $stderr
estimates store l`var'4

reg  l`var'  rti_03  $all_3d2 i.year i.cn  if w_2d==0  & samples==1 , $stderr
estimates store l`var'5

reg  l`var'  rti_03  $all_x2 i.year i.cn  if samples==1 & has_3d==1 & w_2d==1,  $stderr
estimates store l`var'6
}

* something with Italy 2014: it is in any missing, but can be included in regressions (?)
	local l9010 l90101 l90102 l90103 l90104 l90105 l90106
	local l9050 l90501 l90502 l90503 l90504 l90505 l90506
	local l5010 l50101 l50102 l50103 l50104 l50105 l50106

	est table `l9010' , star b(%9.3f) keep(rti*) stat(N)
	est table `l9050' , star b(%9.3f) keep(rti*) stat(N)
	est table `l5010' , star b(%9.3f) keep(rti*) stat(N)

local xy 	  "3d1"
local file_n  "$logs\tab__a_rti3d.tex" 
include 	  "$do_ineq\fancy_tab"
 



**      Task content of jobs
*-------------------------------------------------
local i =0 

foreach var in 9010 9050 5010{
	local ++i 
	foreach v in $tasks{
		 
		reg ar`var' `v' i.year  i.cn, $stderr
		tokenize "`v'" , parse("_")
		di "`1'"	
		est store `1'_`3'_`i'
	}
		
	reg ar`var'  $tasks  $x_3d i.year i.cn if c_code!="FIN" & samples==1 & w_2d==0 , $stderr
	est store all_`i'_2
	
	reg ar`var'  $tasks  $x_ar i.year i.cn if c_code!="FIN" & samples==1 & w_2d==1 & has_3d==1 , $stderr
	est store all_`i'_3

	
	reg  l`var'  $tasks $all_3d2 i.year  i.cn if samples==1 & w_2d==0, $stderr
	est store all_`i'_4

		reg  l`var'  $tasks $all_x2 i.year  i.cn if samples==1 & w_2d==1 & has_3d==1, $stderr
	est store all_`i'_5

	
	}


forvalues i = 1/3{
foreach var in nr_cog nr_pers nr_man r_cog r_man{	
local `var'_`i' `var'_`i' all_`i'_2 all_`i'_3 all_`i'_4  all_`i'_5 
}
local r2_`i' all_`i'_2 all_`i'_3 all_`i'_4  all_`i'_5
}


local xy "tasks_3d"
local file_n "$logs\tab__a_tasks3d.tex" 
include "$do_ineq\fancy_tab"





**     RTI vs changes in occupation structure
*-------------------------------------------------

foreach var in 9010 9050 5010{

reg  l`var'  	change_5 i.year i.cn if samples==1, $stderr
estimates store ch`var'1

reg  l`var'  rti_03 change_5 i.year i.cn if samples==1, $stderr
estimates store ch`var'2

reg  l`var'  rti_03 change_5 $all_3d2 i.year  i.cn if samples==1, $stderr
estimates store ch`var'3
 
reg ar`var'  change_5  i.year i.cn if c_code!="FIN"  & samples==1, $stderr
estimates store ch`var'4 

reg ar`var'  rti_03  change_5  $x_3d i.year i.cn if c_code!="FIN"  & samples==1, $stderr
estimates store ch`var'5

}

local ch9050 ch90501 ch90502 ch90503 ch90504 ch90505 //ch90506    
local ch9010 ch90101 ch90102 ch90103 ch90104 ch90105 //ch90106
local ch5010 ch50101 ch50102 ch50103 ch50104 ch50105 //ch50106

local xy "changes"
local file_n "$logs\tab__a_change3d.tex" 
include "$do_ineq\fancy_tab" 
