*-----------------------------------------------------------------------*
*		               Replication codes for:                           *  
*    ``Within occupation wage dispersion and the task content of job''  *
*-----------------------------------------------------------------------*

* The main data need to be acquired from Eurostat. The sources are:
* https://ec.europa.eu/eurostat/web/microdata/structure-of-earnings-survey
* https://ec.europa.eu/eurostat/web/microdata/european-union-labour-force-survey

* Data on task content of jobs come from O*NET (years 2004/2014) can be downloaded from: 
* https://www.onetcenter.org/db_releases.html

* Data on macroeconomic variables (for appendix) was obtained from Eurostat

* In case of any questions, please contact Lucas van der Velde
* at lvandervelde@grape.org.pl

*-------------------------------------------------------------------------*

version 15

* Paths

* replace with the corresponding links

global do_ineq     "`c(pwd)'"
global graphs	   "$do_ineq\..\graphs"
global logs		   "$do_ineq\..\logs\"

global macro	   "$do_ineq\..\macro"
global onet		   "$do_ineq\..\ONET"
global eu_lfs	   "$do_ineq\..\eu_lfs"
global lfs_proc    "$do_ineq\..\eu_lfs\proc"
global eu_ses	   "$do_ineq\..\eu_ses"
global ses_proc	   "$do_ineq\..\eu_ses\proc"

 

* 0) Technical 
*---------------------------------

* Additional programs that are required to run the codes

capture do 00_programs



* 1) Data preparation
*------------------------------------

* Files for harmonization of EU-SES and EU-LFS 	are available in 
* http://grape.org.pl/project/tasks#harmonizing-inequality-indicators

* Program requires harmonized data to be placed in folders mentioned above.

capture do 01_eu_ses
* file produces the databases with inequality measures. 

capture do 02_lfs_weights
* File recovers occupation weights and occupation specific unemployment rate from EU-LFS

capture do 03_lfs_change_occ
* File recovers change in occupation structure in the 5/10 years prior

capture do 04_tasks
* File creates raw tasks measures merging SOC data to ISCO codes

capture do 05_tasks_merge
* File combines tasks measures and weights from EU-LFS to obtain final measures
* of task dispersion. It also creates a ``time-varying'' measure of task content. 

capture do 06_macro_eurostat
* File loads csv files to stata, files should be in the $macro folder.

capture do 07_main_merge
* File puts together the measures of inequality, task content of jobs and macro data.
* It also includes some diagnostics.


* 2) Descriptive statistics and figures
*----------------------------------------------------

capture do 11_descriptives
* Fle produces Tables 1, 2 and figure 2 in the main paper, and table A4 in appendix

capture do 12_match_desc
* File produces table A2 in the appendix and recovers the share of exact matches
* between SOC10 and ISCO08 (4 digits) 

capture do 13_missings
* File produces Table A3 in the appendix


* 3) Regression Results
*----------------------------------------------------

capture do 21_main_tables
* File produces tables 3, 4 and 5 (other than appendix) 

capture do 22_rob_2d
* File produces tables A5, A6, A7, A8, A9 and Figure A1

capture do 23_rob_3d
* File produces tables A10, A11 and A14

capture do 24_rob_change
* File produces tables A12 and A13


* 4) Other files
*-----------------------------------------------------

* These files are called from other do-files to perform simple tasks

* pub_tables
* File roduces tables for publication. 

* country codes
* File links country codes used by Eurostat with three digit country codes.
